ProLiant Servers (ML,DL,SL)
1753329 Members
5229 Online
108792 Solutions
New Discussion юеВ

Re: After Installing PSP on Redhat Enterprise Linux 5.3 on a DL360 G5 the system hangs on boot

 
David Altobelli
Occasional Advisor

Re: After Installing PSP on Redhat Enterprise Linux 5.3 on a DL360 G5 the system hangs on boot

As mentioned elsewhere in this thread, this is a known problem. This problem is caused by the hp-ilo RPM included in the PSP. RHEL5.3 includes the hpilo module, which replaces the module shipped in the hp-ilo package (hp_ilo module). The problem is caused by hp_ilo, there is not a problem with your distro kernel.

The panic trace will look something like:
RIP: [] :hp_ilo:init_hpqci+0xx/0xxx

This PSP is not supported on RHEL5.3. You will need the 820 version of the PSP, which is not yet released. The release date is not announced yet, I can't share that data.

To avoid the problem, remove the hp-ilo package, or if you already have the problem and have crashed, boot to init level 1, and then remove the hp-ilo package.
David Altobelli
Occasional Advisor

Re: After Installing PSP on Redhat Enterprise Linux 5.3 on a DL360 G5 the system hangs on boot

The 815 (and earlier) hp_ilo module does not account for the case that pci_register_driver() could succeed, but the .probe method would not be called. So, hp_ilo assumes the CpqCi pointer is valid, and causes a NULL pointer dereference.
The fix is pretty simple:

--- drivers/char/hp_ilo/CpqCiKlx.c 25 Apr 2008 14:55:18 -0000 1.3.2.3
+++ drivers/char/hp_ilo/CpqCiKlx.c 23 Jan 2009 18:53:26 -0000
@@ -1994,6 +1994,8 @@ static int __devinit hpqci_pci_probe(str
return (status);
}

+ pci_set_master(pdev);
+
adapterExtension->pdev = pdev;
return (status);
}
@@ -2114,6 +2116,9 @@ Return Value:
}


+ if (!CpqCi)
+ return -ENODEV;
+
adapterExtension = CpqCi;
pdev = CpqCi->pdev;
mmioreg = (CPQCIPHYSICAL)pci_resource_start(pdev, 1); // BAR 1, Offset 0x14

The pci_set_master() is to keep the integrated remote console working, there are some shared resources that can get disabled on hpilo unload. The !CpqCi check turns the crash into a graceful failure.
If you want to build this, make sure you system is set up for module builds (kernel-devel + gcc), and run "cd /opt/hp/hp-ilo; do_your_edits to drivers/char/hp_ilo/CpqCiKlx.c; make".

To work around this in the short term, one could add a "rmmod hpilo" in the start portion of /etc/init.d/hp-ilo. That way, your existing management software would continue to function, and there would be no crash.

case "$1" in
start)
#
-# First test to see if hp-ilo driver is loaded
+# First test to see if hpilo driver from distro is loaded
+#
+ RUNNING=`lsmod | fgrep hpilo`
+ if [ ${#RUNNING} -ne 0 ]; then
+ rmmod hpilo
+ if [ "$?" -ne 0 ] ; then
+ showfailure
+ cmaecho "hp-ilo: Not able to stop hpilo module"
+ exit 1
+ else
+ cmaecho "hp-ilo: Unloaded distribution hpilo module"
+ fi
+ fi
+#
+# Then test to see if hp_ilo driver is loaded
#
RUNNING=`lsmod | fgrep hp_ilo`
if [ ${#RUNNING} -ne 0 ]; then


Long term, the right way will be to upgrade your management software to version 820, which will use the in distro hpilo module, and you will not need the hp-ilo package.
pakazmir
Occasional Contributor

Re: After Installing PSP on Redhat Enterprise Linux 5.3 on a DL360 G5 the system hangs on boot

I've experienced the same problem with a DL580 G4 that was updated to 5.3. I've simply disabled the hp-ilo service and am running okay.

Eagerly waiting for the 820 release.

Thanks,
Peters
THAKUR
Frequent Advisor

Re: After Installing PSP on Redhat Enterprise Linux 5.3 on a DL360 G5 the system hangs on boot

Thanks David...
For such a detailed explanation...

Regards,
AKT
Jimmy Vance
HPE Pro

Re: After Installing PSP on Redhat Enterprise Linux 5.3 on a DL360 G5 the system hangs on boot

Red Hat Enterprise Linux 5.3 includes a newer version of the HP iLO driver and the older driver may panic the system if both are loaded simultaneously.

More details can be found in this RedHat KB article

http://kbase.redhat.com/faq/docs/DOC-15564
No support by private messages. Please ask the forum! 
David_679
New Member

Re: After Installing PSP on Redhat Enterprise Linux 5.3 on a DL360 G5 the system hangs on boot

Jason Balicki
New Member

Re: After Installing PSP on Redhat Enterprise Linux 5.3 on a DL360 G5 the system hangs on boot

I've downloaded the new PSP that was just posted and I can install everything except cpq_cciss. I get:

[root@stlmojbprod01 linux]# rpm -Uvh cpq_cciss-3.6.20-18.rhel5.x86_64.rpm
Preparing... ########################################### [100%]
The currently running kernel (2.6.18-128.1.1.el5) is not
supported by this rpm. The supported kernels are:

2.6.18-128.el5
2.6.18-128.el5xen
2.6.18-53.1.13.el5
2.6.18-53.1.13.el5xen
2.6.18-53.1.14.el5
2.6.18-53.1.14.el5xen
2.6.18-53.1.19.el5
2.6.18-53.1.19.el5xen
2.6.18-53.1.21.el5
2.6.18-53.1.21.el5xen
2.6.18-53.1.4.el5
2.6.18-53.1.4.el5xen
2.6.18-53.1.6.el5
2.6.18-53.1.6.el5xen
2.6.18-53.el5
2.6.18-53.el5xen
2.6.18-8.1.14.el5
2.6.18-8.1.14.el5xen
2.6.18-8.1.15.el5
2.6.18-8.1.15.el5xen
2.6.18-8.el5
2.6.18-8.el5xen
2.6.18-92.1.13.el5
2.6.18-92.1.13.el5xen
2.6.18-92.1.18.el5
2.6.18-92.1.18.el5xen
2.6.18-92.1.1.el5
2.6.18-92.1.1.el5xen
2.6.18-92.el5
2.6.18-92.el5xen

Please boot into a supported kernel before installing this rpm
error: %pre(cpq_cciss-3.6.20-18.x86_64) scriptlet failed, exit status 1
error: install: %pre scriptlet failed (2), skipping cpq_cciss-3.6.20-18

Info:

[root@stlmojbprod01 linux]# cat /etc/redhat-release ; uname -a
Red Hat Enterprise Linux Server release 5.3 (Tikanga)
Linux stlmojbprod01.magellanhealth.com 2.6.18-128.1.1.el5 #1 SMP Mon Jan 26 13:58:24 EST 2009 x86_64 x86_64 x86_64 GNU/Linux
[root@stlmojbprod01 linux]#

Is there an easy solution?

Thanks.